@@ -3,7 +3,7 @@ package Dist::Zilla::Plugin::GitHubREADME::Badge;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 use Moose;
 use Moose::Util::TypeConstraints qw(enum);
@@ -103,7 +103,7 @@ sub add_badges {
         } elsif ($badge eq 'gitter') {
             push @badges, "[![Gitter chat](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/$user_name/$repository_name)";
         } elsif ($badge eq 'cpants') {
-            push @badges, "[![Kwalitee status](http://cpants.cpanauthors.org/dist/$distname.png)](http://cpants.charsbar.org/dist/overview/$distname)";
+            push @badges, "[![Kwalitee status](http://cpants.cpanauthors.org/dist/$distname.png)](https://cpants.cpanauthors.org/dist/$distname)";
         } elsif ($badge eq 'issues') {
             push @badges, "[![GitHub issues](https://img.shields.io/github/issues/$user_name/$repository_name.svg)](https://github.com/$user_name/$repository_name/issues)";
         } elsif ($badge eq 'github_tag') {
